#ifndef AVIFILE_REGISTRYNMS_H
#define AVIFILE_REGISTRYNMS_H

#include "default.h"
#include "avm_stl.h"

/**
 * This namespace provides means to conveniently store and retrieve app-specific
 * data from the registry ( file ~/.avirc ).
 *
 * Function names are self-explanatory. Do not include spaces in first two
 * arguments to avoid collisions. 'def_value' arguments correspond to
 * values which will be returned if needed record is not found in the
 * registry or if registry access fails for some reason.
 */

#define REGISTRY_BEGIN_NAMESPACE    namespace Registry {
#define REGISTRY_END_NAMESPACE      }

/* declaration */

REGISTRY_BEGIN_NAMESPACE;

// change default config directory name .avm/default
void* Init(const char* regname, const char* dirname = ".avm");
int WriteInt(const char* appname, const char* valname, int value);
int ReadInt(const char* appname, const char* valname, int def_value);
int WriteFloat(const char* appname, const char* valname, float value);
float ReadFloat(const char* appname, const char* valname, float def_value);
int WriteString(const char* appname, const char* valname, const char* value);
const char* ReadString(const char* appname, const char* valname, const char* def_value);

REGISTRY_END_NAMESPACE;

//
// For internal usage by avifile applications
// do not try to use elsewhere!
//
// used by defining DECLARE_REGISTRY_SHORTCUT
// before inclusion of this file
#ifdef DECLARE_REGISTRY_SHORTCUT
extern const char* g_pcProgramName;

inline int RI(const char* name, int def)
{
    return Registry::ReadInt(g_pcProgramName, name, def);
}

inline const char* RS(const char* name, const char* def)
{
    return Registry::ReadString(g_pcProgramName, name, def);
}

inline int WI(const char* name, int def)
{
    return Registry::WriteInt(g_pcProgramName, name, def);
}

inline int WS(const char* name, const char* def)
{
    return Registry::WriteString(g_pcProgramName, name, def);
}

#ifdef QSTRING_H

#include <stdlib.h> // atoi

inline int WI(const char* name, const QString& def)
{
    return Registry::WriteInt(g_pcProgramName, name, atoi(def.ascii()));
}

inline int WS(const char* name, const QString& def)
{
    return Registry::WriteString(g_pcProgramName, name, def.ascii());
}
#endif // QSTRING_H

#endif // DECLARE_REGISTRY_SHORTCUT

#endif // AVIFILE_REGISTRYNMS_H
